@@ -1,11 +1,11 @@
-"""
-Templates module for LXMFy bot framework.
+"""Templates module for LXMFy bot framework.
 
 This module provides ready-to-use bot templates with different feature sets.
 """
 
+from .cog_test_bot import CogTestBot
 from .echo_bot import EchoBot
-from .reminder_bot import ReminderBot
 from .note_bot import NoteBot
+from .reminder_bot import ReminderBot
 
-__all__ = ["EchoBot", "ReminderBot", "NoteBot"]
+__all__ = ["EchoBot", "ReminderBot", "NoteBot", "CogTestBot"]
